@@ -62,6 +62,7 @@ guint buffer_cb_id;
 gchar* xmlrpc_id=NULL;
 gchar* xmlrpc_password=NULL;
 gchar* xmlrpc_server=NULL;
+gboolean log_debug_flag=FALSE;
 
 ConIcProxyMode proxy_mode=CON_IC_PROXY_MODE_NONE ;
 gchar* http_proxy_host=NULL;
@@ -91,12 +92,15 @@ void PrintUsage(int argc, char *argv[]) {
 
 void log_debug(gchar *snt){
   FILE *fh;
+  g_print("debug: %s",snt);
+  if(log_debug_flag!=TRUE) {
+    return;
+  }
   fh=fopen(TMP_DEBUG_FILE,"a");
   if(fh==NULL){
     g_print( "Problem appending to  %s: %s\n", TMP_DEBUG_FILE,strerror( errno ));
     return;
   }
-  g_print("debug: %s",snt);
   fprintf(fh,"%s",snt);
   fclose(fh);
 }
@@ -642,6 +646,16 @@ void gconf_key_changed_callback(GConfClient* gconf_client,
 				      NULL);
     }
   }
+
+  if(strcmp(entry->key,"/apps/osso/phonehome/log_debug")==0 && entry->value!=NULL){
+    if(entry->value->type == GCONF_VALUE_BOOL){
+      debug_snt=g_strdup_printf("Changing log_debug with %i\n", gconf_value_get_bool(entry->value));
+      log_debug(debug_snt);
+      g_free(debug_snt);
+      g_free(xmlrpc_server);
+      log_debug_flag=gconf_client_get_bool(gconf_client, "/apps/osso/phonehome/log_debug", NULL);
+    } else {log_debug("Type is not bool\n");}
+  }
   
 
 }
@@ -1174,6 +1188,9 @@ int main(int argc, char *argv[]) {
   xmlrpc_server=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/server",
 			  NULL);
   
+  log_debug_flag=gconf_client_get_bool(gconf_client, "/apps/osso/phonehome/log_debug", NULL);
+  if(log_debug_flag==NULL) {log_debug_flag=FALSE;}
+
   if(xmlrpc_server==NULL){
     xmlrpc_server=DEFAULT_XMLRPC_SERVER;
   }
